@@ -19,6 +19,15 @@ class Util : public QObject
 public:
     explicit Util(QObject *parent = nullptr);
 
+public:
+    enum Status {
+        Normal = 0,
+        Connecting,
+        NeedsConfiguration,
+        Timeout,
+    };
+    Q_ENUM(Status);
+
 public:
     /**
      * Returns the @p iconName if the current icon theme contains an icon with that name,
